#!/usr/bin/env node --harmony
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var pkg = require("../package.json");
var program = require("commander");
var api_service_1 = require("./model/api.service");
require("./helpers/array.helpers");
var storage_service_1 = require("./model/storage.service");
var update_notifier_1 = require("./update-notifier");
var date_fns_1 = require("date-fns");
var pace_table_1 = require("./views/pace.table");
var hours_table_1 = require("./views/hours.table");
var timesheet_table_1 = require("./views/timesheet.table");
program
    .name("When I Work")
    .option("-l, --login", "make a login request")
    .option("-p, --pace", "show pace table")
    .option("-t, --timesheet", "show time sheet table")
    .version(pkg.version)
    .parse(process.argv);
(function () {
    new update_notifier_1.UpdateNotifier(pkg);
    var api = new api_service_1.ApiService();
    var storage = new storage_service_1.StorageService();
    if (program.login) {
        return api
            .login(storage.username, storage.password)
            .then(function (response) {
            console.log("Save the following lines to your ~/.wheniwork file:");
            console.log("WHENIWORK_USERID=" + response.user.id);
            console.log("WHENIWORK_TOKEN=" + response.token);
        })
            .catch(function (error) {
            console.error("Whoops, login failed. Make sure your credentials are correct and try again.");
        });
    }
    if (!storage.hasAll()) {
        console.error("Run `wheniwork -l` to login before continuing");
    }
    var start = date_fns_1.startOfWeek(new Date());
    var end = date_fns_1.endOfWeek(new Date());
    api
        .dateRange(start, end)
        .then(function (dateRange) {
        new hours_table_1.HoursTable(dateRange); // default
        if (program.timesheet)
            new timesheet_table_1.TimeSheetTable(dateRange);
        if (program.pace)
            new pace_table_1.PaceTable(dateRange);
    })
        .catch(function (error) {
        console.error("The date range request failed, please check your config file and try again");
    });
})();
//# sourceMappingURL=cli.js.map