"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var date_fns_1 = require("date-fns");
var chalk_1 = require("chalk");
var format_utilities_1 = require("./format.utilities");
var CalculatorUtilities = /** @class */ (function () {
    function CalculatorUtilities() {
        this.format = new format_utilities_1.FormatUtilities();
    }
    CalculatorUtilities.prototype.workedSoFar = function (startTime) {
        var minutesWorked = date_fns_1.differenceInMinutes(new Date(), startTime);
        return minutesWorked / 60;
    };
    CalculatorUtilities.prototype.estimateEndTime = function (time) {
        var hoursToAdd = 8 - time.length;
        time.end_time = date_fns_1.addHours(new Date(), hoursToAdd);
        return time;
    };
    /**
     * Converts a simple time string to JavaScript date.
     *
     * @param {string} time A simple time layout.
     * @returns {Date} A converted date.
     */
    CalculatorUtilities.prototype.convertTimeToDate = function (time) {
        var splitTime = time.split("").filter(function (i) { return !isNaN(i); });
        if (splitTime.length === 3)
            splitTime.unshift("0");
        var hour = Number("" + splitTime[0] + splitTime[1]);
        var minutes = Number("" + splitTime[2] + splitTime[3]);
        var date = new Date();
        date.setHours(hour, minutes);
        return date;
    };
    CalculatorUtilities.prototype.difference = function (hours, comparison) {
        var difference = Number((hours - comparison).toFixed(2));
        var differenceOut = "";
        switch (true) {
            case difference > 0:
                differenceOut = chalk_1.default.green("+" + this.format.hours(difference));
                break;
            case difference == 0:
                differenceOut = chalk_1.default.yellow(this.format.hours(0));
                break;
            case difference < 0:
                differenceOut = chalk_1.default.red("-" + this.format.hours(Math.abs(difference)));
            default:
                difference;
        }
        return differenceOut;
    };
    return CalculatorUtilities;
}());
exports.CalculatorUtilities = CalculatorUtilities;
//# sourceMappingURL=calculator.utilities.js.map