"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var node_fetch_1 = require("node-fetch");
var storage_service_1 = require("./storage.service");
var date_range_1 = require("../dates/date-range");
var ApiService = /** @class */ (function () {
    function ApiService() {
        this.storage = new storage_service_1.StorageService();
        this.url = "https://api.wheniwork.com/2";
    }
    /**
     * Makes a login request to the api.
     *
     * `POST /login`
     *
     * @param username The account username
     * @param password The account password
     * @returns The login response data
     */
    ApiService.prototype.login = function (username, password) {
        return node_fetch_1.default(this.url + "/login", {
            body: JSON.stringify({
                username: username,
                password: password
            }),
            headers: {
                "content-type": "application/json",
                "W-Key": this.storage.key
            },
            method: "POST"
        })
            .then(function (response) { return response.json(); })
            .catch(function (error) { return console.error(error); });
    };
    ApiService.prototype.times = function (start, end) {
        return node_fetch_1.default(this.url + "/times/?user_id=" + this.storage.userId + "&start=" + start + "&end=" + end, {
            headers: {
                "content-type": "application/json",
                "W-Token": this.storage.token
            },
            method: "GET"
        })
            .then(function (response) { return response.json(); })
            .then(function (json) { return json.times; })
            .catch(function (error) { return console.error(error); });
    };
    ApiService.prototype.dateRange = function (start, end) {
        return this.times(start, end).then(function (times) { return new date_range_1.DateRange(times); });
    };
    return ApiService;
}());
exports.ApiService = ApiService;
//# sourceMappingURL=api.service.js.map